@@ -4,11 +4,7 @@
 // Copyright 2007-2015 by Apple Inc.
 // Copyright 2002-2005 by Easy Software Products.
 //
-// These coded instructions, statements, and computer programs are the
-// property of Apple Inc. and are protected by Federal copyright
-// law.  Distribution and use rights are outlined in the file "LICENSE.txt"
-// which should have been included with this file.  If this file is
-// file is missing or damaged, see the license at "http://www.cups.org/".
+// Licensed under Apache License v2.0.  See the file "LICENSE" for more information.
 //
 
 //
@@ -24,7 +20,7 @@
 // Local functions...
 //
 
-static void	usage(void);
+static void	usage(void) _CUPS_NORETURN;
 
 
 //
@@ -84,7 +80,6 @@ main(int  argc,				// I - Number of command-line arguments
 
 	  default :			// Unknown
 	      usage();
-	      break;
 	}
     }
     else
@@ -104,7 +99,7 @@ main(int  argc,				// I - Number of command-line arguments
       for (g = (ppdcGroup *)d->groups->first(); g; g = (ppdcGroup *)d->groups->next())
 	for (o = (ppdcOption *)g->options->first(); o; o = (ppdcOption *)g->options->next())
 	{
-	  if ((compo = composite->find_option(o->name->value)) == NULL)
+	  if (!composite->find_option(o->name->value))
 	    composite->add_option(new ppdcOption(o));
 	}
 
